@@ -1,12 +1,12 @@
 from dataclasses import dataclass
-from typing import Any, List
+from typing import Any, List, Union
 
 
 @dataclass
 class cyWeatherAPIResponseHourlyWindStruct:
     datetime: str
-    speed: float
-    direction: float
+    speed: Union[float, int]
+    direction: Union[float, int]
 
 
 @dataclass
@@ -47,6 +47,7 @@ class cyWeatherAPIResponseHourlyStruct:
     temperature: List[cyWeatherAPIResponseHourlySimpleDatetimeValuePair]
     humidity: List[cyWeatherAPIResponseHourlySimpleDatetimeValuePair]
     cloudrate: List[cyWeatherAPIResponseHourlySimpleDatetimeValuePair]
+    skycon: List[cyWeatherAPIResponseHourlySimpleDatetimeValuePair]
     pressure: List[cyWeatherAPIResponseHourlySimpleDatetimeValuePair]
     visibility: List[cyWeatherAPIResponseHourlySimpleDatetimeValuePair]
     dswrf: List[cyWeatherAPIResponseHourlySimpleDatetimeValuePair]
