@@ -1,10 +1,10 @@
 from dataclasses import dataclass
 
-from cyapi.models.alert import cyWeatherAPIResponseAlertStruct
-from cyapi.models.hourly import cyWeatherAPIResponseHourlyStruct
-from cyapi.models.minutely import cyWeatherAPIResponseMinutelyStruct
-from cyapi.models.realtime import cyWeatherAPIResponseRealtimeStruct
-from cyapi.models.daily import cyWeatherAPIResponseDailyStruct
+from cy_weather_api.models.alert import cyWeatherAPIResponseAlertStruct
+from cy_weather_api.models.daily import cyWeatherAPIResponseDailyStruct
+from cy_weather_api.models.hourly import cyWeatherAPIResponseHourlyStruct
+from cy_weather_api.models.minutely import cyWeatherAPIResponseMinutelyStruct
+from cy_weather_api.models.realtime import cyWeatherAPIResponseRealtimeStruct
 
 
 @dataclass
